/*
 *  Elementary WebView
 *
 * Copyright (c) 2000 - 2011 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: Ryuan Choi <ryuan.choi@samsung.com>, Eunmi Lee <eunmi15.lee@samsung.com>, Kangil Han <kangil.han@samsung.com>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef ELEMENTARY_WEBKIT_H
#define ELEMENTARY_WEBKIT_H

#include <Elementary.h>
#include <EWebKit.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @file    Elementary_webview.h
 * @brief   This file contains APIs of the elm-webview, one of EFL library.
 * @author  Eunmi Lee (eunmi15.lee@samsung.com)
 * @author  Ryuan Choi (ryuan.choi@samsung.com)
 * @author  Mariusz Grzegorczyk (mariusz.g@samsung.com)
 * @version 1.0
 * @date    2010.10.14  Modified for doxygen
 * @date    2010.10.16  Modified for doxygen
 * @date    2011.12.02  Remove deprecated APIs
 * @date    2012.02.08  Add new APIs
 */

/**
 * @addtogroup InternetFW
 * @{
 *
 * @defgroup ElementaryWebView
 * @version 1.0
 * @brief Elementary WebView is a mobile enhanced webview component based webkit.
 * @par Details
 *  Elementary WebView is a shared library to provide Elementary based webview component which support panning, zooming and other mobile behaviors. \n\n
 *
 */

/**
 * @addtogroup ElementaryWebView
 * @{
 */

typedef struct _Elm_WebView_Context_Menu_Data Elm_WebView_Context_Menu_Data;
struct _Elm_WebView_Context_Menu_Data
{
	Ewk_Context_Menu* webkit_context_menu;
	Ewk_Hit_Test_Result_Context hit_test_result_context;
	Evas_Event_Mouse_Down mouse_down_event;
	Eina_Bool is_text_selection;
};

typedef struct _Elm_WebView_Create_Webview_Data Elm_WebView_Create_Webview_Data;
struct _Elm_WebView_Create_Webview_Data
{
	Evas_Object* webview;
	int navigation_action;
	const char* frame_name;
	Eina_Bool javascript;
	Eina_Bool isMobile;
};

typedef Eina_Bool (*Elm_WebView_Scheme_Cb)(Evas_Object *obj, const char *uri);

/**
 * @fn Evas_Object *elm_webview_add(Evas_Object *parent)
 * @brief create a new webview and add the webview to a parent object.
 *
 * The major difference between an webview and an WebKit object is that mobile-device specific feature
 * are provided or not. The webview supports panning, zooming and fitting contents and so on, while the WebKit object don't.
 *
 * @remarks If you need to use ewk api provided by the WebKit object, you should get the WebKit object using elm_webview_webkit_view_get after creating the webview object.
 *
 * @param[in]   parent  The parent object that will contain webview object
 * @return  The newly created object is returned.  NULL if it failed to create one.
 *
 */
EAPI Evas_Object *elm_webview_add(Evas_Object *parent, ... );

/**
 * @fn Evas_Object *elm_webview_webkit_get(Evas_Object *obj)
 * @brief Get the webkit object to call ewk API directly for fine control.
 *
 * @param[in]   obj     An WebView object
 * @return  The WebKit object or NULL on errors
 */
EINA_DEPRECATED Evas_Object *elm_webview_webkit_get(Evas_Object *obj);

/**
 * @fn Evas_Object *elm_webview_webkit_view_get(Evas_Object *obj)
 * @brief Get the webkit object to call ewk API directly for fine control.
 *
 * @param[in]   obj     An WebView object
 * @return  The WebKit object or NULL on errors
 */
EAPI Evas_Object *elm_webview_webkit_view_get(Evas_Object *obj);

/**
 * @fn void elm_webview_events_feed_set(Evas_Object *obj, Eina_Bool feed)
 * @brief Set/Clear the property to feed received mouse events to the webkit object
 *
 * When setting to EINA_TRUE, elm_webview treates all incoming touch events like mouse events.
 * In other word, all events are fed to an web page (WebKit object) directly so that no panning/zooming in UI will be performed
 * This is usually set to EINA_TRUE, in a map application where mouse events are consumed for map panning, not page panning.
 *
 * @remarks Difference between feed and block
 *  As a default(feeding=Off, blocking=Off), the webview receive events (panning, zooming, touch events)
 *  By feeding events, the WebKit will receive the events (no panning, no zooming, but fed to WebKit as mouse events).
 *  By blocking events, Both WebKit and webview can't receive events(no events are allowed).
 *
 * @param[in]   obj     An WebView object
 * @param[in]   feed    A boolean value to to enable/disable event feeding to webkit object.
 */
EAPI void         elm_webview_events_feed_set(Evas_Object *obj, Eina_Bool feed);

/**
 * @fn Eina_Bool elm_webview_events_feed_get(Evas_Object *obj)
 * @brief Get the current value of the property of event feeding
 *
 * @param[in]   obj     The WebView object
 * @return  EINA_TRUE if feeding event property is enabled, otherwise EINA_FALSE is returned.
 */
EAPI Eina_Bool    elm_webview_events_feed_get(Evas_Object *obj);

/**
 * @fn void elm_webview_auto_fitting_set(Evas_Object *obj, Eina_Bool enable)
 * @brief enable/disable the property for fitting rendered web page content to device screen width right after web page loading.
 *
 * If It was EINA_TRUE, elm_webview treate touch event like mouse event.
 * So, panning and zooming are not allowed.
 *
 * @param[in]   obj     The WebView object
 * @param[in]   enable  A boolean to enable/disable auto fitting
 */
EAPI void         elm_webview_auto_fitting_set(Evas_Object *obj, Eina_Bool enable);

/**
 * @fn Eina_Bool elm_webview_auto_fitting_get(Evas_Object *obj)
 * @brief get the property value for fitting rendered web page content to device screen width right after web page loading.
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE when auto fitting is enabled, otherwise EINA_FALSE.
 */
EAPI Eina_Bool    elm_webview_auto_fitting_get(Evas_Object *obj);

/**
 * @fn void elm_webview_uri_set(Evas_Object *obj, const char *uri)
 * @brief Set uri to be loaded in the given WebView object
 *
 * It will direct WebKit to load the specified URI. Basically, it is the same to ewk_view_uri_set() except
 * that it can be called without any specified protocol in URI.
 * The default protocol is HTTP.
 *
 * @param[in] obj An WebView object
 * @param[in] uri URI string to be loaded. http: can be ommitted
 */
EAPI void         elm_webview_uri_set(Evas_Object *obj, const char *uri);

/**
 * @fn const char  *elm_webview_uri_get(const Evas_Object *obj)
 * @brief Get the current uri loaded
 *
 * @param[in] obj An WebView object
 * @return The current uri or NULL on errors
 */
EAPI const char  *elm_webview_uri_get(const Evas_Object *obj);

/**
 * @fn void elm_webview_scheme_callback_set(Evas_Object *obj, const char *scheme, Elm_WebView_Scheme_Cb func)
 * @brief Add callback to handle schemes.
 *
 * When a browser loads an web page, a user-specified action, or callback for each scheme (e.g) tel:, mailto, smsto: mmsto) can be connctected by using this API
 *
 * @param[in] obj An WebView object
 * @param[in] scheme A scheme which a developer needs to intercept
 * @param[in] func callback when user choose link which involved @scheme
 *
 * @par_Example
 * @code
   Eina_Bool user_cb(Evas_Object* webview, const char* uri)
   {
       //add proper action for this uri
       return EINA_FALSE;//load this scheme uri if EINA_TRUE, return value of schemes defaults to EINA_FALSE without http, https, file.
   }

   ...

  //this is an example for mailto scheme. change scheme which you want.
   elm_webview_scheme_callback_set(webview, "mailto", user_cb);
 @endcode
 *
 */
EAPI void         elm_webview_scheme_callback_set(Evas_Object *obj, const char *scheme, Elm_WebView_Scheme_Cb func);

/**
 * @fn void elm_webview_layout_width_set_to_container(Evas_Object *obj)
 * @brief Set layout width to container geometry.
 *
 * Comment should be revised
 * After setting this webview's layout width will be set to container
 * that contains this webview. After resizing layout width will be updated.
 *
 * @param [in]  obj The WebView object
 */
EAPI void         elm_webview_layout_width_set_to_container(Evas_Object *obj);

/**
 * @fn void elm_webview_input_field_zoom_set(Evas_Object* obj, Eina_Bool zoom)
 * @brief turn on/off the input field zoom effect
 *
 * If you want to turn on/off the input field zoom effect, you can use this API.
 * The input field zoom effect is turned on as a default.
 *
 * @param [in]  obj  The WebView object
 * @param [in]  zoom EINA_TRUE if you want to use input field zoom, EINA_FALSE otherwise.
 */
EAPI void         elm_webview_input_field_zoom_set(Evas_Object* obj, Eina_Bool zoom);

/**
 * @fn Eina_Bool elm_webview_input_field_zoom_get(Evas_Object* obj)
 * @brief Get the property for the input field zoom effect
 *
 * @param [in]  obj  The WebView object
 * @return  Eina_TRUE when the input field zoom effect is enabled, otherwise EINA_FALSE.
 */
EAPI Eina_Bool    elm_webview_input_field_zoom_get(Evas_Object* obj);

/**
 * @fn void elm_webview_auto_suspend_set(Evas_Object* obj, Eina_Bool auto_suspend)
 * @brief turn on/off the auto suspend during panning/zooming for achieving silky panning and zooming
 *
 * If you want to suspend javascript, network, and rendering during paning and zooming automatically, you can use this API.
 * The auto suspend feature is turned off as a default.
 *
 * @param [in]  obj  The WebView object
 * @param [in]  zoom EINA_TRUE if you want to use auto suspend, EINA_FALSE otherwise.
 */
EAPI void         elm_webview_auto_suspend_set(Evas_Object* obj, Eina_Bool auto_suspend);

/**
 * @fn void elm_webview_pause(Evas_Object* obj)
 * @brief Pause the webview operation: javascript, network, rendering, etc.
 *
 * @param [in]  obj  The WebView object
 */
EAPI void         elm_webview_pause(Evas_Object* obj);

/**
 * @fn void elm_webview_resume(Evas_Object* obj)
 * @brief Resume the webview operation: javascript, network, rendering, etc.
 *
 * @param [in]  obj  The WebView object
 */
EAPI void         elm_webview_resume(Evas_Object* obj);

/**
 * @fn void elm_webview_enable_default_context_menu_set(Evas_Object* obj, Eina_Bool enable)
 * @brief Set the property for an webview object to show default context menu items.
 *
 * When EINA_TRUE, elm_webview will show default context menu items when context menu appear
 *
 * @param[in]   obj     An WebView object
 * @param[in]   enable  a boolean to enable/disable default value
 */
EINA_DEPRECATED void elm_webview_enable_default_context_menu_set(Evas_Object* obj, Eina_Bool enable);

/**
 * @fn Eina_Bool elm_webview_enable_default_context_menu_get(Evas_Object* obj)
 * @brief Get the property for the webview object to show default context menu.
 *
 * @param[in]   obj     The WebView object
 * @return  EINA_TRUE When default context menu is enabled, otherwise EINA_FALSE.
 */
EINA_DEPRECATED Eina_Bool elm_webview_enable_default_context_menu_get(Evas_Object* obj);

/**
 * @fn void elm_webview_context_menu_item_selected(Evas_Object* obj, Ewk_Context_Menu_Item* webkit_context_menu_item);
 * @brief Informs webview about that a context menu item is selected
 *
 * @param[in]   obj     The WebView object
 * @param[in]   a pointer to webkit_context_menu_item containing a selected item
 */
EAPI void         elm_webview_context_menu_item_selected(Evas_Object* obj, Ewk_Context_Menu_Item* webkit_context_menu_item);

/**
 * @fn void elm_webview_enable_default_touch_set(Evas_Object* obj, Eina_Bool enable);
 * @brief enable/disable default touch processor of webview
 * 
 * Add description about how default touch process behave simply
 *
 * @param[in]   obj     An WebView object
 * @param[in]   enable  boolean value to enable default touch or not
 */
EAPI void elm_webview_enable_default_touch_set(Evas_Object* obj, Eina_Bool enable);

/**
 * @fn void elm_webview_horizontal_panning_hold_set(Evas_Object* obj, Eina_Bool hold);
 * @brief hold/unhold horizontal panning.
 * horizontal panning will be stopped during hold, and will be done during unhold.
 *
 * @param[in]   obj     The WebView object
 * @param[in]   enable  boolean value to hold/unhold horizontal panning
 */
EAPI void elm_webview_horizontal_panning_hold_set(Evas_Object* obj, Eina_Bool hold);

/**
 * @fn Eina_Bool elm_webview_horizontal_panning_hold_get(Evas_Object* obj);
 * @brief Get hold/unhold horizontal panning status.
 *
 * @param[in]   obj     The WebView object
 * @return  EINA_TRUE When horizontal panning hold set is enabled, otherwise EINA_FALSE.
 */
EAPI Eina_Bool elm_webview_horizontal_panning_hold_get(Evas_Object* obj);

/**
 * @fn void elm_webview_vertical_panning_hold_set(Evas_Object* obj, Eina_Bool hold);
 * @brief hold/unhold vertical panning.
 * vertical panning will be stopped during hold, and will be done during unhold.
 *
 * @param[in]   obj     The WebView object
 * @param[in]   enable  boolean value to hold/unhold vertical panning
 */
EAPI void elm_webview_vertical_panning_hold_set(Evas_Object* obj, Eina_Bool hold);

/**
 * @fn Eina_Bool elm_webview_vertical_panning_hold_get(Evas_Object* obj);
 * @brief Get hold/unhold vertical panning status.
 * vertical panning will be stopped during hold, and will be done during unhold.
 *
 * @param[in]   obj     The WebView object
 * @return  EINA_TRUE When vertical panning hold set is enabled, otherwise EINA_FALSE.
 */
EAPI Eina_Bool elm_webview_vertical_panning_hold_get(Evas_Object* obj);

/**
 * @fn void elm_webview_text_selection_clear(Evas_Object *obj)
 * @brief clear text selection area
 *
 * @param[in]   obj     The WebView object
 */
EAPI void elm_webview_text_selection_clear(Evas_Object *obj);

/**
 * @fn void elm_webview_cbhm_run(Evas_Object *obj)
 * @brief Runs clipboard application.
 *
 * @param[in]   obj     The WebView object
 */
EAPI void elm_webview_cbhm_run(Evas_Object* obj);

/**
 * @fn void elm_webview_use_mouse_down_delay_set(Evas_Object *obj, Eina_Bool use_mouse_down_delay)
 * @brief set use_mouse_down_delay
 *
 * @param[in] obj The WebView object.
 * @param[in] use_mouse_down_delay value to set to the use_mouse_down_delay variable.
 */
EAPI void elm_webview_use_mouse_down_delay_set(Evas_Object *obj, Eina_Bool use_mouse_down_delay);

/**
 * @fn Eina_Bool elm_webview_use_mouse_down_delay_get(Evas_Object *obj)
 * @brief get use_mouse_down_delay value
 *
 * @param[in] obj The WebView object.
 * @return EINA_TRUE if use_mouse_down_delay is true. EINA_FALSE if else or on errors.
 */
EAPI Eina_Bool elm_webview_use_mouse_down_delay_get(Evas_Object *obj);
/**
 * @}
 */

/**
 * @fn void elm_webview_use_smart_zoom_set(Evas_Object *obj, Eina_Bool use_smart_zoom)
 * @brief set use_smart_zoom
 *
 * @param[in] obj The WebView object.
 * @param[in] use_smart_zoom value to set to the use_smart_zoom variable.
 */
EAPI void elm_webview_use_smart_zoom_set(Evas_Object *obj, Eina_Bool use_smart_zoom);

/**
 * @fn Eina_Bool elm_webview_use_smart_zoom_get(Evas_Object *obj)
 * @brief get use_smart_zoom
 *
 * @param[in] obj The WebView object.
 * @return EINA_TRUE if use_smart_zoom is true. EINA_FALSE if else or on errors.
 */
EAPI Eina_Bool elm_webview_use_smart_zoom_get(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_fixed_position_get(Evas_Object *obj)
 * @brief gets if WebView should fix its position.
 *
 * @param[in] obj The WebView object.
 * @return EINA_TRUE if WebView should fix its position. EINA_FALSE otherwise.
 */
EAPI Eina_Bool elm_webview_fixed_position_get(Evas_Object *obj);

/**
 * @fn void elm_webview_fixed_position_set(Evas_Object *obj, Eina_Bool enable);
 * @brief enables/disables fixed position of WebView.
 *
 * @param[in]   obj     An WebView object
 * @param[in]   enable  boolean value to enable fixed position of WebView or not.
 */
EAPI void elm_webview_fixed_position_set(Evas_Object *obj, Eina_Bool enable);

/**
 * @fn void elm_webview_show_ime_on_autofocus_set(Evas_Object *obj, Eina_Bool enable);
 * @brief sets whether autofocus events from web sites will trigger showing virtual keyboard or not.
 *
 * @param[in] obj the WebView object.
 * @param[in] enable a boolean value to enable autofocus events triggering showing virtual keyboard.
 */
EAPI void elm_webview_show_ime_on_autofocus_set(Evas_Object *obj, Eina_Bool enable);

/**
 * @fn Eina_Bool elm_webview_show_ime_on_autofocus_get(Evas_Object *obj)
 * @brief gets if autofocus will trigger showing keyboard or not.
 *
 * @param[in] obj the WebView object.
 * @return EINA_TRUE if autofocus will trigger showing keyboard. EINA_FALSE otherwise.
 */
EAPI Eina_Bool elm_webview_show_ime_on_autofocus_get(Evas_Object *obj);

/**
 * @fn void elm_webview_use_tilt_zoom_set(Evas_Object *obj, Eina_Bool enable);
 * @brief sets whether application use tilt zoom or not.
 *
 * @param[in] obj the WebView object.
 * @param[in] enable a boolean value to enable tilt zoom.
 */
EAPI void elm_webview_use_tilt_zoom_set(Evas_Object *obj, Eina_Bool enable);

/**
 * @fn Eina_Bool elm_webview_show_magnifier_get(Evas_Object *obj);
 * @brief gets whether webview shows magnifier for text selection or not.
 *
 * @param[in] obj the WebView object.
 * @return EINA_TRUE if webview shows magnifier. EINA_FALSE otherwise.
 */
EAPI Eina_Bool elm_webview_show_magnifier_get(Evas_Object *obj);

/**
 * @fn void elm_webview_show_magnifier_set(Evas_Object *obj, Eina_Bool enable);
 * @brief sets whether webview shows magnifier for text selection or not.
 *
 * @param[in] obj the WebView object.
 * @param[in] enable a boolean value to enable magnifier.
 */
EAPI void elm_webview_show_magnifier_set(Evas_Object *obj, Eina_Bool enable);

/**
 * @fn Eina_Bool elm_webview_back(Evas_Object *obj)
 * @brief Go back in the history.
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_back(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_back_possible(Evas_Object *obj)
 * @brief Query if it's possible to navigate backward one item in the history
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE if it's possible to navigate backward one item in the history, EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_back_possible(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_forward(Evas_Object *obj)
 * @brief Go forward in the history.
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_forward(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_forward_possible(Evas_Object *obj)
 * @brief Query if it's possible to navigate forward one item in the history
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE if it's possible to navigate forward one item in the history, EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_forward_possible(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_navigate(Evas_Object *obj, int steps)
 * @brief Navigate back or forward in the history.
 *
 * @param[in]   obj     An WebView object
 * @param[in]   steps   If positive navigates that amount forwards, if negative does backwards
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_navigate(Evas_Object *obj, int steps);

/**
 * @fn Eina_Bool elm_webview_navigate_possible(Evas_Object *obj, int steps)
 * @brief Query if it's possible to navigate given @a steps in the history.
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE if it's possible to navigate @a steps in the history, EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_navigate_possible(Evas_Object *obj, int steps);

/**
 * @fn Eina_Bool elm_webview_contents_set(Evas_Object *obj, const char *contents, size_t contents_size, const char *mime_type, const char *encoding, const char *base_uri)
 * @brief Request to load the given contents
 *
 * @param[in]   obj             An WebView object
 * @param[in]   contents        Contents to load
 * @param[in]   contents_size   Size of @a contents (in bytes). If @c 0 is given length of @a contents is used
 * @param[in]   mime_type       Type of @a contents data. If @c 0 is given "text/html" is assumed
 * @param[in]   encoding        Encoding for @a contents data, if @c 0 is given "UTF-8" is assumed
 * @param[in]   base_uri        Base uri to use for relative resources. may be @c 0. If provided @b must be an absolute uri
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_contents_set(Evas_Object *obj, const char *contents, size_t contents_size, const char *mime_type, const char *encoding, const char *base_uri);

/**
 * @fn Eina_Bool elm_webview_reload(Evas_Object *obj)
 * @brief Request to reload current document
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_reload(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_stop(Evas_Object *obj)
 * @brief Request to to stop loading
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_stop(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_zoom_set(Evas_Object *obj, float zoom)
 * @brief Set the current zoom level
 *
 * @param[in]   obj     An WebView object
 * @param[in]   zoom    A new level to set
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_zoom_set(Evas_Object *obj, float zoom);

/**
 * @fn float elm_webview_zoom_get(Evas_Object *obj)
 * @brief Get the current zoom level
 *
 * @param[in]   obj     An WebView object
 * @return  Current zoom level in use on success or @c -1.0 on failure
 */
EAPI float elm_webview_zoom_get(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_zoom_in_possible(Evas_Object *obj)
 * @brief Query if it's possible to zoom in
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE if it's possible to zoom in, EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_zoom_in_possible(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_zoom_out_possible(Evas_Object *obj)
 * @brief Query if it's possible to zoom out
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE if it's possible to zoom out, EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_zoom_out_possible(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_scroll_by(Evas_Object *obj, int dx, int dy)
 * @brief Scroll @a delta_x and @a delta_y pixels from the current position of scroll
 *
 * @param[in]   obj     An WebView object
 * @param[in]   dx      Horizontal offset to scroll
 * @param[in]   dy      Vertical offset to scroll
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_scroll_by(Evas_Object *obj, int dx, int dy);

/**
 * @fn Eina_Bool elm_webview_scroll_pos_set(Evas_Object *obj, int x, int y)
 * @brief Set the scroll position
 *
 * @param[in]   obj     An WebView object
 * @param[in]   x       Horizontal position to scroll
 * @param[in]   y       Vertical position to scroll
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_scroll_pos_set(Evas_Object *obj, int x, int y);

/**
 * @fn Eina_Bool elm_webview_scroll_pos_get(Evas_Object *obj, int* x, int* y)
 * @brief Get the scroll position
 *
 * @param[in]   obj     An WebView object
 * @param[out]  x       Horizontal position
 * @param[out]  y       Vertical position
 * @return  EINA_TRUE on success or EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_scroll_pos_get(Evas_Object *obj, int *x, int *y);

/**
 * @fn const char *elm_webview_title_get(const Evas_Object *obj)
 * @brief Get the current title
 *
 * @param[in]   obj     An WebView object
 * @return  Current title on success or @c NULL on failure
 */
EAPI const char *elm_webview_title_get(const Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_text_search(const Evas_Object *obj, const char* string, Eina_Bool case_sensitive, Eina_Bool forward, Eina_Bool wrap)
 * @brief Searches the given string in a document.
 *
 * @param[in]   obj             An WebView object
 * @param[in]   string          Reference string to search
 * @param[in]   case_sensitive  If search should be case sensitive or not
 * @param[in]   forward         If search is from cursor and on or backwards
 * @param[in]   wrap            If search should wrap at the end
 * @return  EINA_TRUE if the given string was found, EINA_FALSE if not or failure
 */
EAPI Eina_Bool elm_webview_text_search(const Evas_Object *obj, const char* string, Eina_Bool case_sensitive, Eina_Bool forward, Eina_Bool wrap);

/**
 * @fn unsigned int elm_webview_text_matches_mark(Evas_Object *obj, const char *string, Eina_Bool case_sensitive, Eina_Bool highlight, unsigned int limit)
 * @brief Mark matches the given string in a document.
 *
 * @param[in]   obj             An WebView object
 * @param[in]   string          Reference string to match
 * @param[in]   case_sensitive  If match should be case sensitive or not
 * @param[in]   highlight       If matches should be highlighted
 * @param[in]   limit           Maximum amount of matches, or zero to unlimited
 * @return  Number of matched @a string
 */
EAPI unsigned int elm_webview_text_matches_mark(Evas_Object *obj, const char *string, Eina_Bool case_sensitive, Eina_Bool highlight, unsigned int limit);

/**
 * @fn Eina_Bool elm_webview_text_matches_unmark_all(Evas_Object *obj)
 * @brief Unmark all marked matches in a document.
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE on success or EINA_FALSE on failure
 */
EAPI Eina_Bool elm_webview_text_matches_unmark_all(Evas_Object *obj);

/**
 * @fn Eina_Bool elm_webview_text_matches_highlight_set(Evas_Object *obj, Eina_Bool highlight)
 * @brief Set if should highlight matches marked with elm_webview_text_matches_mark().
 *
 * @param[in]   obj         An WebView object
 * @param[in]   highlight   EINA_TRUE if matches are highlighted, EINA_FALSE if not
 * @return  EINA_TRUE on success or EINA_FALSE on failure
 */
EAPI Eina_Bool elm_webview_text_matches_highlight_set(Evas_Object *obj, Eina_Bool highlight);

/**
 * @fn Eina_Bool elm_webview_text_matches_highlight_get(Evas_Object *obj)
 * @brief Get if should highlight matches marked with elm_webview_text_matches_mark().
 *
 * @param[in]   obj     An WebView object
 * @return  EINA_TRUE if matches are highlighted, EINA_FALSE otherwise
 */
EAPI Eina_Bool elm_webview_text_matches_highlight_get(Evas_Object *obj);

#ifdef __cplusplus
}
#endif

#endif /*#ifndef ELEMENTARY_WEBKIT_H*/
